summaryrefslogtreecommitdiffstats
path: root/akregator/src/feedlistview.h
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/feedlistview.h')
-rw-r--r--akregator/src/feedlistview.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/akregator/src/feedlistview.h b/akregator/src/feedlistview.h
index 1a5111f4..52952089 100644
--- a/akregator/src/feedlistview.h
+++ b/akregator/src/feedlistview.h
@@ -41,7 +41,7 @@ class NodeListView : public KListView
Q_OBJECT
TQ_OBJECT
public:
- NodeListView( TQWidget *tqparent = 0, const char *name = 0 );
+ NodeListView( TQWidget *parent = 0, const char *name = 0 );
virtual ~NodeListView();
/** sets the feed list to show. Disconnects from the old feed list, if there is any. */
@@ -92,7 +92,7 @@ public slots:
void slotItemBegin();
/** select last item in the list */
void slotItemEnd();
/** go to tqparent item */
void slotItemLeft();
/** go to first child */
void slotItemRight();
@@ -133,7 +133,7 @@ public: // compat with KDE-3.x assertions, remove for KDE 4
int cx, int cy, int cw, int ch );
virtual void contentsDragMoveEvent(TQDragMoveEvent* event);
virtual bool acceptDrag(TQDropEvent *event) const;
- virtual void movableDropEvent(TQListViewItem* tqparent, TQListViewItem* afterme);
+ virtual void movableDropEvent(TQListViewItem* parent, TQListViewItem* afterme);
virtual TQDragObject *dragObject();
@@ -155,10 +155,10 @@ protected slots:
/** called when a node is added to the tree. If no item for the node exists, it will be created */
virtual void slotNodeAdded(TreeNode* node);
/** Called when a node in the tree is taken out of the tree (tqparent->removeChild())
Removes a node and its tqchildren from the tree. Note that it doesn't delete the corresponding view items (get deleted only when the node itself gets deleted) */
- virtual void slotNodeRemoved(Folder* tqparent, TreeNode* node);
+ virtual void slotNodeRemoved(Folder* parent, TreeNode* node);
/** deletes the item belonging to the deleted node */
virtual void slotNodeDestroyed(TreeNode* node);
@@ -195,7 +195,7 @@ class TagNodeListView : public NodeListView
Q_OBJECT
TQ_OBJECT
public:
- TagNodeListView(TQWidget *tqparent = 0, const char *name = 0) {}
+ TagNodeListView(TQWidget *parent = 0, const char *name = 0) {}
virtual ~TagNodeListView() {}
private:
@@ -92,7 +92,7 @@ public slots:
/** select last item in the list */
void slotItemEnd();
- /** go to tqparent item */
+ /** go to parent item */
void slotItemLeft();
/** go to first child */
@@ -155,10 +155,10 @@ protected slots:
/** called when a node is added to the tree. If no item for the node exists, it will be created */
virtual void slotNodeAdded(TreeNode* node);
- /** Called when a node in the tree is taken out of the tree (tqparent->removeChild())
+ /** Called when a node in the tree is taken out of the tree (parent->removeChild())
Removes a node and its tqchildren from the tree. Note that it doesn't delete the corresponding view items (get deleted only when the node itself gets deleted) */